==> kubefirst-2.6.1.ventura.bottle.tar.gz: kubefirst/2.6.1/README.md <==
<!-- markdownlint-disable MD041 -->
<p align="center">
  <picture>
    <source media="(prefers-color-scheme: dark)" srcset="images/kubefirst-light.svg" alt="Kubefirst Logo">
    <img alt="" src="images/kubefirst.svg">
  </picture>
</p>
<p align="center">
  GitOps Infrastructure & Application Delivery Platform
</p>

<p align="center">
  <a href="https://docs.kubefirst.io/">Install</a>&nbsp;|&nbsp;
  <a href="https://twitter.com/kubefirst">Twitter</a>&nbsp;|&nbsp;
  <a href="https://www.linkedin.com/company/kubefirst">LinkedIn</a>&nbsp;|&nbsp;
  <a href="https://join.slack.com/t/kubefirst/shared_invite/zt-r0r9cfts-OVnH0ooELDLm9n9p2aU7fw">Slack</a>&nbsp;|&nbsp;
  <a href="https://kubeshop.io/blog-projects/kubefirst">Blog</a>
</p>

<p align="center">
  <a href="https://github.com/konstructio/kubefirst/releases"><img title="Release" src="https://img.shields.io/github/v/release/kubefirst/kubefirst"/></a>
  <!-- <a href=""><img title="Docker builds" src="https://img.shields.io/docker/automated/kubeshop/tracetest"/></a> -->
  <a href="https://github.com/konstructio/kubefirst/releases"><img title="Release date" src="https://img.shields.io/github/release-date/kubefirst/kubefirst"/></a>
</p>

---

# Kubefirst CLI

The Kubefirst CLI creates instant GitOps platforms that integrate some of the best tools in cloud native from scratch in minutes.

Each of our platforms have install guides that detail the prerequesites, commands, and resulting platform that you'll receive.

- [k3d (local)](https://docs.kubefirst.io/k3d/overview/)
- [AWS](https://docs.kubefirst.io/aws/overview/)
- [Civo](https://docs.kubefirst.io/civo/overview/)
- [DigitalOcean](https://docs.kubefirst.io/do/overview/)

In beta:

- [Akamai](https://docs.kubefirst.io/akamai/overview)
- [Google Cloud](https://docs.kubefirst.io/gcp/overview/)
- [K3s](https://docs.kubefirst.io/k3s/overview)
- [Vultr](https://docs.kubefirst.io/vultr/overview/)

## Overview

<https://docs.kubefirst.io>

![kubefirst architecture diagram](images/kubefirst-arch.png)

## Feed K-Ray

Feed K-Ray a GitHub star ⭐ above to bookmark our project and keep K-Ray happy!!

[![Star History Chart](https://api.star-history.com/svg?repos=kubefirst/kubefirst&type=Date)](https://star-history.com/#kubefirst/kubefirst&Date)

## Contributions

We want to thank all of our contributors who created a pull request to fix a bug, add a new feature or update the [documentation](https://github.com/konstructio/kubefirst-docs/). We also value a lot contributions in the form of bug reporting or feature requests: it helps us continuously make kubefirst better. Lastly, helping the users in our Slack community, or helping us share the love on social media are also ways in which you support us tremendously. We know your time is valuable, and we can't thank you enough for everything you do: we wouldn't be where we are without you!

A special thanks to [DrummyFloyd](https://github.com/DrummyFloyd) who, in addition to adding support for k3s, is a champion all around within our community and the kubefirst project 🫶

If you want to help in any capacity, check [CONTRIBUTING.md](CONTRIBUTING.md).

==> kubefirst-2.7.4.ventura.bottle.tar.gz: kubefirst/2.7.4/README.md <==
<!-- markdownlint-disable MD041 -->
<p align="center">
  <picture>
    <source media="(prefers-color-scheme: dark)" srcset="images/kubefirst-light.svg" alt="Kubefirst Logo">
    <img alt="" src="images/kubefirst.svg">
  </picture>
</p>
<p align="center">
  GitOps Infrastructure & Application Delivery Platform
</p>

<p align="center">
  <a href="https://kubefirst.konstruct.io/docs/">Install</a>&nbsp;|&nbsp;
  <a href="https://twitter.com/kubefirst">Twitter</a>&nbsp;|&nbsp;
  <a href="https://www.linkedin.com/company/kubefirst">LinkedIn</a>&nbsp;|&nbsp;
  <a href="https://join.slack.com/t/kubefirst/shared_invite/zt-r0r9cfts-OVnH0ooELDLm9n9p2aU7fw">Slack</a>&nbsp;|&nbsp;
  <a href="https://kubeshop.io/blog-projects/kubefirst">Blog</a>
</p>

<p align="center">
  <a href="https://github.com/konstructio/kubefirst/releases"><img title="Release" src="https://img.shields.io/github/v/release/kubefirst/kubefirst"/></a>
  <!-- <a href=""><img title="Docker builds" src="https://img.shields.io/docker/automated/kubeshop/tracetest"/></a> -->
  <a href="https://github.com/konstructio/kubefirst/releases"><img title="Release date" src="https://img.shields.io/github/release-date/kubefirst/kubefirst"/></a>
</p>

---

# Kubefirst CLI

The Kubefirst CLI creates instant GitOps platforms that integrate some of the best tools in cloud native from scratch in minutes.

Each of our platforms have install guides that detail the prerequesites, commands, and resulting platform that you'll receive.

- [k3d (local)](https://kubefirst.konstruct.io/docs/k3d/overview)
- [AWS](https://kubefirst.konstruct.io/docs/aws/overview)
- [Civo](https://kubefirst.konstruct.io/docs/civo/overview)
- [DigitalOcean](https://kubefirst.konstruct.io/docs/do/overview)

In beta:

- [Akamai](https://docs.kubefirst.io/akamai/overview)
- [Google Cloud](https://kubefirst.konstruct.io/docs/gcp/overview)
- [K3s](https://kubefirst.konstruct.io/docs/k3s/overview)
- [Vultr](https://kubefirst.konstruct.io/docs/vultr/overview)

## Overview

<https://kubefirst.konstruct.io/docs/>

![kubefirst architecture diagram](images/kubefirst-arch.png)

## Feed K-Ray

Feed K-Ray a GitHub star ⭐ above to bookmark our project and keep K-Ray happy!!

[![Star History Chart](https://api.star-history.com/svg?repos=kubefirst/kubefirst&type=Date)](https://star-history.com/#kubefirst/kubefirst&Date)

## Contributions

We want to thank all of our contributors who created a pull request to fix a bug, add a new feature or update the [documentation](https://github.com/konstructio/kubefirst-docs/). We also value a lot contributions in the form of bug reporting or feature requests: it helps us continuously make kubefirst better. Lastly, helping the users in our Slack community, or helping us share the love on social media are also ways in which you support us tremendously. We know your time is valuable, and we can't thank you enough for everything you do: we wouldn't be where we are without you!

A special thanks to [DrummyFloyd](https://github.com/DrummyFloyd) who, in addition to adding support for k3s, is a champion all around within our community and the kubefirst project 🫶

If you want to help in any capacity, check [CONTRIBUTING.md](CONTRIBUTING.md).
